@@ -12,8 +12,9 @@ class Action(enum.Enum):
 
 
 class Listener:
-    def __init__(self):
+    def __init__(self, backspace_debug=False):
         self.tabbed = False
+        self.backspace_debug = backspace_debug
 
     def handle_key(self, key):
         action = Action.invalid
@@ -22,12 +23,18 @@ class Listener:
             self.tabbed = True
         elif key == "\n" and self.tabbed:
             raise StoppingSignal(silent=True)
+        elif self.backspace_debug and key == chr(8):
+            action = Action.del_word
+            self.tabbed = False
+        elif key == 263 and self.backspace_debug:
+            action = Action.del_char
+            self.tabbed = False
         elif key == 263:
             action = Action.del_word
             self.tabbed = False
         elif isinstance(key, int):
             self.tabbed = False
-        elif key == chr(127):
+        elif key in chr(127):
             action = Action.del_char
             self.tabbed = False
         elif key == " ":
